@@ -1,17 +1,18 @@
-
-from peek_plugin_base.server.PluginServerEntryHookABC import PluginServerEntryHookABC
+from peek_plugin_base.server.PluginLogicEntryHookABC import PluginLogicEntryHookABC
 from peek_plugin_base.client.PluginClientEntryHookABC import PluginClientEntryHookABC
 from peek_plugin_base.agent.PluginAgentEntryHookABC import PluginAgentEntryHookABC
 from typing import Type
 
-__version__ = '2.5.6'
+__version__ = '3.1.1'
 
 
-def peekServerEntryHook() -> Type[PluginServerEntryHookABC]:
-    from .private.server.ServerEntryHook import ServerEntryHook
-    return ServerEntryHook
+def peekLogicEntryHook() -> Type[PluginLogicEntryHookABC]:
+    from .private.server.LogicEntryHook import LogicEntryHook
+
+    return LogicEntryHook
 
 
 def peekAgentEntryHook() -> Type[PluginAgentEntryHookABC]:
     from .private.agent.AgentEntryHook import AgentEntryHook
+
     return AgentEntryHook
